@@ -14,18 +14,18 @@
 #' \item The criterion for selecting the number of quantizers is implemented in 
 #' this function. The user has to choose a grid \code{testN} of possible values 
 #' in which \code{N} will be selected. It actually minimizes some bootstrap 
-#' estimated version of the MSE (Mean Squared Error). More precisely, for 
+#' estimated version of the ISE (Integrated Squared Error). More precisely, for 
 #' \code{N} fixed, it calculates the sum according to \code{alpha} of 
-#' \code{hatMSE_N} and then minimizes the resulting vector to get \code{N_opt}.
+#' \code{hatISE_N} and then minimizes the resulting vector to get \code{N_opt}.
 #'  However, the user can choose to select a different value of \code{N_opt} for
 #'  each \code{alpha} by setting \code{same_N=FALSE}. In this case, the vector 
-#'  \code{N_opt} is obtained by minimizing each column of \code{hatME_N} 
+#'  \code{N_opt} is obtained by minimizing each column of \code{hatISE_N} 
 #'  separately. The reason why \code{same_N=TRUE} by default is that taking 
-#'  \code{N_opt} according to \code{alpha} could provide crossing condtional 
-#'  quantile curves (rarely observed for not too close values of \code{alpha}. 
+#'  \code{N_opt} according to \code{alpha} could provide crossing conditional 
+#'  quantile curves (rarely observed for not too close values of \code{alpha}). 
 #'  The function \code{\link{plot.select.N.QuantifQuantile}} 
-#'  illustrates the selection of \code{N_opt}. If the graph is not globally convex, the arguments 
-#'  \code{testN} should be adapted.}
+#'  illustrates the selection of \code{N_opt}. If the graph is not decreasing 
+#'  then increasing, the argument \code{testN} should be adapted.}
 #'  
 #' @param X matrix of covariates.
 #' @param Y vector of response variables.
@@ -44,26 +44,26 @@
 #' quantiles. The number of columns is the number of considered values for \code{x} 
 #' and the number of rows the size of the order vector \code{alpha}.}
 #' @return \item{N_opt}{Optimal selected value for \code{N}. An integer if 
-#' \code{same_N}=TRUE and a vector of integers of length \code{length(alpha)} 
+#' \code{same_N=TRUE} and a vector of integers of length \code{length(alpha)} 
 #' otherwise.}
-#' @return \item{hatMSE_N}{The matrix of estimated MSE provided by our selection 
+#' @return \item{hatISE_N}{The matrix of estimated ISE provided by our selection 
 #' criterion for \code{N} before taking the mean according to \code{alpha}. The 
 #' number of columns is then \code{length(testN)} and the number of rows 
 #' \code{length(alpha)}.}
 #' @return \item{hatq_N}{A 3-dimensional array containing the estimated 
-#' conditional quantiles for each considered value for \code{N}.}
+#' conditional quantiles for each considered value for \code{alpha}, \code{x} and \code{N}.}
 #' @return \item{X}{The matrix of covariates.}
 #' @return \item{Y}{The vector of response variables.}
 #' @return \item{x}{The considered vector of values for \code{x} in q_alpha(x).}
 #' @return \item{alpha}{The considered vector of order for the quantiles.}
 #' @return \item{testN}{The considered grid of values for \code{N} that were tested.}
 #'  
-#' @references Charlier, I. and Paindaveine, D. and Saracco, J. (2014),
-#' \emph{Conditional quantiles estimation through optimal quantization}, 
-#' Submitted.
-#' @references Charlier, I. and Paindaveine, D. and Saracco, J. (2014),
-#' \emph{Numerical study of a conditional quantile estimator based on optimal 
-#' quantization}, Manuscript in preparation.
+#' @references Charlier, I. and Paindaveine, D. and Saracco, J.,
+#' \emph{Conditional quantile estimation through optimal quantization}, 
+#' Journal of Statistical Planning and Inference, to appear.
+#' @references Charlier, I. and Paindaveine, D. and Saracco, J.,
+#' \emph{Conditional quantile estimator based on optimal 
+#' quantization: from theory to practice}, Submitted.
 #' 
 #' @seealso \code{\link{QuantifQuantile}} and \code{\link{QuantifQuantile.d2}} 
 #' for particular dimensions one and two.
@@ -134,8 +134,8 @@ QuantifQuantile.d <- function(X, Y, x, alpha = c(0.05, 0.25,
     }
     
     m <- length(x)/d
-    hatMSE_N <- array(0, dim = c(length(alpha), length(testN)))
-    hatq_N <- array(0, dim = c(m, length(alpha), length(testN)))
+    hatISE_N <- array(0, dim = c(length(alpha), length(testN)))
+    hatq_N <- array(0, dim = c(length(alpha), m, length(testN)))
     
     primeX <- array(X[, sample(c(1:n), n * (B + tildeB), replace = T)], 
         dim = c(d, n, (B + tildeB)))
@@ -145,7 +145,7 @@ QuantifQuantile.d <- function(X, Y, x, alpha = c(0.05, 0.25,
     for (jj in 1:length(testN)) {
         N <- testN[jj]
       
-        hatX <- choice.grid(X, N, B = B, tildeB = tildeB)$opti_grid
+        hatX <- choice.grid(X, N, ng = (B + tildeB))$opti_grid
         # projection of the sample X on the B+tildeB optimal grids
         projXboot <- array(0, dim = c(d, n, B + tildeB))
         # index of the grid on which X is projected
@@ -242,44 +242,43 @@ QuantifQuantile.d <- function(X, Y, x, alpha = c(0.05, 0.25,
             mean)
         
         i <- which(N == testN)
-        hatq_N[, , i] <- hatq
+        hatq_N[, , i] <- t(hatq)
         
-        # the last tilde B are used to estimate the MSE
+        # the last tilde B are used to estimate the ISE
         HATq <- array(rep(hatq, tildeB), dim = c(m, length(alpha), 
             tildeB))
-        hatMSE <- (HATq - Hatq[, , c((1 + B):(B + tildeB)), drop = FALSE])^2
-        hatMSE <- apply(hatMSE, 2, sum)/(m * tildeB)
-        hatMSE_N[, i] <- hatMSE
+        hatISE <- (HATq - Hatq[, , c((1 + B):(B + tildeB)), drop = FALSE])^2
+        hatISE <- apply(hatISE, 2, sum)/(m * tildeB)
+        hatISE_N[, i] <- hatISE
         
         print(N)
     }
     
     if(same_N){
       #choice of optimal N
-      hatMSEmean_N <- apply(hatMSE_N, 2, mean)
-      i_opt <- which.min(hatMSEmean_N)
-      #optimal value for N chosen as minimizing the sum of hatMSE for the 
+      hatISEmean_N <- apply(hatISE_N, 2, mean)
+      i_opt <- which.min(hatISEmean_N)
+      #optimal value for N chosen as minimizing the sum of hatISE for the 
       # different alpha's
       N_opt <- testN[i_opt]
       
       # table of the associated estimated conditional quantiles
       hatq_opt <- hatq_N[, , i_opt, drop = F]
-      hatq_opt <- matrix(hatq_opt, ncol = length(alpha))
-      hatq_opt <- t(hatq_opt)
+      hatq_opt <- matrix(hatq_opt, nrow = length(alpha))
     }else{
       #choice of optimal N
-      i_opt <- apply(hatMSE_N, 1, which.min)
-      #optimal value for N chosen as minimizing the sum of hatMSE for the 
+      i_opt <- apply(hatISE_N, 1, which.min)
+      #optimal value for N chosen as minimizing the sum of hatISE for the 
       # different alpha's
       N_opt <- testN[i_opt]
       # table of the associated estimated conditional quantiles
       hatq_opt <- array(0, dim = c(length(alpha), length(x)))
       for(i in 1:length(alpha)){
-        hatq_opt[i, ] <- hatq_N[,i , i_opt[i]]
+        hatq_opt[i, ] <- hatq_N[i, , i_opt[i]]
       }
     }
     output <- list(hatq_opt = hatq_opt, N_opt = N_opt, 
-        hatMSE_N = hatMSE_N, hatq_N = hatq_N, X = X, Y = Y, x = x, 
+        hatISE_N = hatISE_N, hatq_N = hatq_N, X = X, Y = Y, x = x, 
         alpha = alpha, testN = testN)
     class(output) <- "QuantifQuantile"
     output
