@@ -6,12 +6,12 @@
 ##' the \code{\link{QuantifQuantile}}, \code{\link{QuantifQuantile.d2}} or 
 ##' \code{\link{QuantifQuantile.d}} functions.
 ##' @param \dots Not used.
-##' @references Charlier, I. and Paindaveine, D. and Saracco, J. (2014),
-##' \emph{Conditional quantiles estimation through optimal quantization}, 
-##' Submitted.
-##' @references Charlier, I. and Paindaveine, D. and Saracco, J. (2014),
-##' \emph{Numerical study of a conditional quantile estimator based on optimal 
-##' quantization}, Manuscript in preparation.
+#' @references Charlier, I. and Paindaveine, D. and Saracco, J.,
+#' \emph{Conditional quantile estimation through optimal quantization}, 
+#' Journal of Statistical Planning and Inference, to appear.
+#' @references Charlier, I. and Paindaveine, D. and Saracco, J.,
+#' \emph{Conditional quantile estimator based on optimal 
+#' quantization: from theory to practice}, Submitted.
 
 ##' @seealso \code{\link{QuantifQuantile}}, \code{\link{QuantifQuantile.d2}} and
 ##'  \code{\link{QuantifQuantile.d}}
@@ -27,7 +27,7 @@
 ##' print(res)
 ##'
 ##' @method print QuantifQuantile
-##' @S3method print QuantifQuantile
+# @S3method print QuantifQuantile
 ##' @export print.QuantifQuantile
 print.QuantifQuantile <- function(x, ...) {
     stopifnot(class(x)=="QuantifQuantile")
@@ -42,8 +42,8 @@ print.QuantifQuantile <- function(x, ...) {
                   "optimal value for N selected among testN by our criterion")
     res[2, ] <- c("$hatq_opt", 
                   "the estimated conditional quantiles obtained with N_opt")
-    res[3, ] <- c("$hatMSE_N", 
-                  "estimated MSE as a function of N")
+    res[3, ] <- c("$hatISE_N", 
+                  "estimated ISE as a function of N")
     
     print(res)
     
